#!/usr/bin/env node

import { ArgumentParser }  from 'argparse'
import open from 'open'
import { description, version } from '../../package.json'
import { createServer } from '../backend'

async function showProductionError() {
  const clc = await import('cli-color')
  console.error(clc.red('Do not run this in production!'))
  process.exit(1)

}

if (process.env.NODE_ENV === 'production') {
  showProductionError();
}

const parser = new ArgumentParser({
  description: description,
})

parser.add_argument('-v', '--version', {
  action: 'version',
  version: version
})

parser.add_argument('-o', '--open', {
  action: 'store_true',
  help: 'Open server URL in default browser on start',
})

parser.add_argument('-H', '--host', {
  type: 'str',
  required: false,
  help: 'Host to run on (default: undefined)',
})

parser.add_argument('-p', '--port', {
  type: 'int',
  default: 8001,
  help: 'Port to run on (default: 8001)',
})

const args = parser.parse_args()

const app = createServer()
const host = process.env.HOST || args.host
const port = process.env.PORT || args.port
const server = app.listen(port, host)
server.on('listening', () => {
  const { address, port } = server.address()
  let url = `http://${address}:${port}`
  if (!host && address !== '0.0.0.0') {
    url += ` (alternatively http://0.0.0.0:${port})`
  }
  console.log(`  dynamodb-admin listening on ${url}`)

  if (args.open) {
    open(url)
  }
})

